from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Memory_RAM = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'628128_DIP32_SSOP32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'628128_DIP32_SSOP32'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'http://www.futurlec.com/Datasheet/Memory/628128.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\n628128_DIP32_SSOP32\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='16',name='GND',func=pin_types.PWRIN),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='~{CS1}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='CS2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'628128_TSOP32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'628128_TSOP32'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'http://www.futurlec.com/Datasheet/Memory/628128.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\n628128_TSOP32\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='24',name='GND',func=pin_types.PWRIN),
            Pin(num='8',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='23',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='25',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='26',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='27',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='28',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='29',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{CS1}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CS2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS4C256M16D3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS4C256M16D3'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-96_9.0x13.0mm_Layout2x3x16_P0.8mm'], 'footprint':'Package_BGA:BGA-96_9.0x13.0mm_Layout2x3x16_P0.8mm', 'keywords':'DDR3 DRAM MEMORY', 'description':'', 'datasheet':'https://www.alliancememory.com/wp-content/uploads/pdf/ddr3/4GB-AS4C256M16D3.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nAS4C256M16D3\n\nDDR3 DRAM MEMORY', 'pins':[
            Pin(num='A1',name='VDDQ',func=pin_types.PWRIN),
            Pin(num='A8',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='A9',name='VSS',func=pin_types.PWRIN),
            Pin(num='B1',name='VSSQ',func=pin_types.PWRIN),
            Pin(num='B2',name='VDD',func=pin_types.PWRIN),
            Pin(num='B3',name='VSS',func=pin_types.PASSIVE),
            Pin(num='B9',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='C1',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='C9',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='D1',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='D2',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='D8',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='D9',name='VDD',func=pin_types.PASSIVE),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='E2',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='E3',name='DQ0',func=pin_types.BIDIR),
            Pin(num='E8',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='E9',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='F1',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='F2',name='DQ2',func=pin_types.BIDIR),
            Pin(num='F7',name='DQ1',func=pin_types.BIDIR),
            Pin(num='F8',name='DQ3',func=pin_types.BIDIR),
            Pin(num='F9',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='G1',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='G2',name='DQ6',func=pin_types.BIDIR),
            Pin(num='G7',name='VDD',func=pin_types.PASSIVE),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE),
            Pin(num='G9',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='H1',name='VREFDQ',func=pin_types.PWRIN),
            Pin(num='H2',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='H3',name='DQ4',func=pin_types.BIDIR),
            Pin(num='H7',name='DQ7',func=pin_types.BIDIR),
            Pin(num='H8',name='DQ5',func=pin_types.BIDIR),
            Pin(num='H9',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='J2',name='VSS',func=pin_types.PASSIVE),
            Pin(num='J8',name='VSS',func=pin_types.PASSIVE),
            Pin(num='K2',name='VDD',func=pin_types.PASSIVE),
            Pin(num='K8',name='VDD',func=pin_types.PASSIVE),
            Pin(num='L2',name='~{CS}',func=pin_types.INPUT),
            Pin(num='L7',name='A10/AP',func=pin_types.INPUT),
            Pin(num='M1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='M9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='N1',name='VDD',func=pin_types.PASSIVE),
            Pin(num='N2',name='A3',func=pin_types.INPUT),
            Pin(num='N3',name='A0',func=pin_types.INPUT),
            Pin(num='N7',name='A12/~{BC}',func=pin_types.INPUT),
            Pin(num='N9',name='VDD',func=pin_types.PASSIVE),
            Pin(num='P1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='P2',name='A5',func=pin_types.INPUT),
            Pin(num='P3',name='A2',func=pin_types.INPUT),
            Pin(num='P7',name='A1',func=pin_types.INPUT),
            Pin(num='P8',name='A4',func=pin_types.INPUT),
            Pin(num='P9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='R1',name='VDD',func=pin_types.PASSIVE),
            Pin(num='R2',name='A7',func=pin_types.INPUT),
            Pin(num='R3',name='A9',func=pin_types.INPUT),
            Pin(num='R7',name='A11',func=pin_types.INPUT),
            Pin(num='R8',name='A6',func=pin_types.INPUT),
            Pin(num='R9',name='VDD',func=pin_types.PASSIVE),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='T2',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='T3',name='A13',func=pin_types.INPUT),
            Pin(num='T7',name='A14',func=pin_types.INPUT),
            Pin(num='T8',name='A8',func=pin_types.INPUT),
            Pin(num='T9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='A2',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='B7',name='~{UDQS}',func=pin_types.BIDIR,unit=1),
            Pin(num='B8',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='C2',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='UDQS',func=pin_types.BIDIR,unit=1),
            Pin(num='C8',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='UDM',func=pin_types.INPUT,unit=1),
            Pin(num='D7',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='LDM',func=pin_types.INPUT,unit=1),
            Pin(num='F3',name='LDQS',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='~{LDQS}',func=pin_types.BIDIR,unit=1),
            Pin(num='J1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J3',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='CK',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K1',name='ODT',func=pin_types.INPUT,unit=1),
            Pin(num='K3',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='K7',name='~{CK}',func=pin_types.INPUT,unit=1),
            Pin(num='K9',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='L1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='L3',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='L8',name='ZQ',func=pin_types.INPUT,unit=1),
            Pin(num='L9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M2',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='M3',name='BA2',func=pin_types.INPUT,unit=1),
            Pin(num='M7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='M8',name='VREFCA',func=pin_types.PWRIN,unit=1),
            Pin(num='N8',name='BA1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS4C4M16SA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS4C4M16SA'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC166 PC143 64Mb 16Mbx4 MEMORY', 'description':'', 'datasheet':'https://www.alliancememory.com/wp-content/uploads/pdf/dram/64M-AS4C4M16SA-CI_v3.0_March%202015.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nAS4C4M16SA\n\nSDRAM Synchronous DRAM PC166 PC143 64Mb 16Mbx4 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10/AP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC/RFU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS6C1616', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS6C1616'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-48_18.4x12mm_P0.5mm'], 'footprint':'Package_SO:TSOP-I-48_18.4x12mm_P0.5mm', 'keywords':'memory SRAM', 'description':'', 'datasheet':'https://www.alliancememory.com/wp-content/uploads/pdf/AS6C1616-TSOPI.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nAS6C1616\n\nmemory SRAM', 'pins':[
            Pin(num='1',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='WE#',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CE2',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='UB#',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='LB#',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='CE#',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='OE#',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ15',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A19',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AS6C4008-55PCN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AS6C4008-55PCN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-32_W15.24mm'], 'footprint':'Package_DIP:DIP-32_W15.24mm', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'https://www.alliancememory.com/wp-content/uploads/pdf/AS6C4008.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nAS6C4008-55PCN\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='16',name='VSS',func=pin_types.PWRIN),
            Pin(num='32',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='DQ0',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='DQ1',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='DQ2',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='DQ3',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='DQ4',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='DQ5',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='DQ6',func=pin_types.TRISTATE,unit=1),
            Pin(num='21',name='DQ7',func=pin_types.TRISTATE,unit=1),
            Pin(num='22',name='CE#',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='OE#',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='WE#',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY7C199', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY7C199'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nCY7C199\n\n', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='D0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='D1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='D2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='D3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='D4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='D5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='D6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='D7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A13',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ESP-PSRAM32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ESP-PSRAM32'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'32 Mbit serial pseudo SRAM MEMORY', 'description':'', 'datasheet':'https://www.espressif.com/sites/default/files/documentation/esp-psram32_datasheet_en.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nESP-PSRAM32\n\n32 Mbit serial pseudo SRAM MEMORY', 'pins':[
            Pin(num='1',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SO/SIO',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='SIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SI/SIO',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SCLK',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='SIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'H5AN8G8NAFR-UHC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'H5AN8G8NAFR-UHC'}), 'ref_prefix':'U', 'fplist':['Package_BGA:FBGA-78_7.5x11mm_Layout2x3x13_P0.8mm'], 'footprint':'Package_BGA:FBGA-78_7.5x11mm_Layout2x3x13_P0.8mm', 'keywords':'DDR4 DRAM MEMORY', 'description':'', 'datasheet':'https://www.skhynix.com/product/filedata/fileDownload.do?seq=7687', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nH5AN8G8NAFR-UHC\n\nDDR4 DRAM MEMORY', 'pins':[
            Pin(num='A1',name='VDD',func=pin_types.PWRIN),
            Pin(num='A2',name='VSSQ',func=pin_types.PWRIN),
            Pin(num='A3',name='TDQS_c',func=pin_types.OUTPUT),
            Pin(num='A7',name='TDQS_t/~{DM/DBI}',func=pin_types.BIDIR),
            Pin(num='A8',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='A9',name='VSS',func=pin_types.PWRIN),
            Pin(num='B1',name='VPP',func=pin_types.PWRIN),
            Pin(num='B2',name='VDDQ',func=pin_types.PWRIN),
            Pin(num='B3',name='DQS_c',func=pin_types.BIDIR),
            Pin(num='B7',name='DQ1',func=pin_types.BIDIR),
            Pin(num='B8',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='B9',name='ZQ',func=pin_types.PASSIVE),
            Pin(num='C1',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='C2',name='DQ0',func=pin_types.BIDIR),
            Pin(num='C3',name='DQS_t',func=pin_types.BIDIR),
            Pin(num='C7',name='VDD',func=pin_types.PASSIVE),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE),
            Pin(num='C9',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='D1',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='D2',name='DQ4',func=pin_types.BIDIR),
            Pin(num='D3',name='DQ2',func=pin_types.BIDIR),
            Pin(num='D7',name='DQ3',func=pin_types.BIDIR),
            Pin(num='D8',name='DQ5',func=pin_types.BIDIR),
            Pin(num='D9',name='VSSQ',func=pin_types.PASSIVE),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='E2',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='E3',name='DQ6',func=pin_types.BIDIR),
            Pin(num='E7',name='DQ7',func=pin_types.BIDIR),
            Pin(num='E8',name='VDDQ',func=pin_types.PASSIVE),
            Pin(num='E9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='F1',name='VDD',func=pin_types.PASSIVE),
            Pin(num='F2',name='NC/C2/ODT1',func=pin_types.PASSIVE),
            Pin(num='F3',name='ODT',func=pin_types.INPUT),
            Pin(num='F7',name='CK_t',func=pin_types.INPUT),
            Pin(num='F8',name='CK_c',func=pin_types.INPUT),
            Pin(num='F9',name='VDD',func=pin_types.PASSIVE),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='G2',name='NC/C0/CKE1',func=pin_types.PASSIVE),
            Pin(num='G3',name='CKE',func=pin_types.INPUT),
            Pin(num='G7',name='~{CS}',func=pin_types.INPUT),
            Pin(num='G8',name='NC/C1/~{CS1}',func=pin_types.PASSIVE),
            Pin(num='G9',name='TEN',func=pin_types.INPUT),
            Pin(num='H1',name='VDD',func=pin_types.PASSIVE),
            Pin(num='H2',name='A14/~{WE}',func=pin_types.INPUT),
            Pin(num='H3',name='~{ACT}',func=pin_types.INPUT),
            Pin(num='H7',name='A15/~{CAS}',func=pin_types.INPUT),
            Pin(num='H8',name='A16/~{RAS}',func=pin_types.INPUT),
            Pin(num='H9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='J1',name='VREFCA',func=pin_types.PASSIVE),
            Pin(num='J2',name='BG0',func=pin_types.INPUT),
            Pin(num='J3',name='A10/AP',func=pin_types.INPUT),
            Pin(num='J7',name='A12/~{BC}',func=pin_types.INPUT),
            Pin(num='J8',name='BG1',func=pin_types.INPUT),
            Pin(num='J9',name='VDD',func=pin_types.PASSIVE),
            Pin(num='K1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='K2',name='BA0',func=pin_types.INPUT),
            Pin(num='K3',name='A4',func=pin_types.INPUT),
            Pin(num='K7',name='A3',func=pin_types.INPUT),
            Pin(num='K8',name='BA1',func=pin_types.INPUT),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE),
            Pin(num='L1',name='~{RESET}',func=pin_types.INPUT),
            Pin(num='L2',name='A6',func=pin_types.INPUT),
            Pin(num='L3',name='A0',func=pin_types.INPUT),
            Pin(num='L7',name='A1',func=pin_types.INPUT),
            Pin(num='L8',name='A5',func=pin_types.INPUT),
            Pin(num='L9',name='~{ALERT}',func=pin_types.OPENCOLL),
            Pin(num='M1',name='VDD',func=pin_types.PASSIVE),
            Pin(num='M2',name='A8',func=pin_types.INPUT),
            Pin(num='M3',name='A2',func=pin_types.INPUT),
            Pin(num='M7',name='A9',func=pin_types.INPUT),
            Pin(num='M8',name='A7',func=pin_types.INPUT),
            Pin(num='M9',name='VPP',func=pin_types.PASSIVE),
            Pin(num='N1',name='VSS',func=pin_types.PASSIVE),
            Pin(num='N2',name='A11',func=pin_types.INPUT),
            Pin(num='N3',name='PAR',func=pin_types.INPUT),
            Pin(num='N7',name='A17/NC',func=pin_types.PASSIVE),
            Pin(num='N8',name='A13',func=pin_types.INPUT),
            Pin(num='N9',name='VDD',func=pin_types.PASSIVE)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7006PF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7006PF'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'dual-port ram', 'description':'', 'datasheet':'https://www.idt.com/document/dst/7006-data-sheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7006PF\n\ndual-port ram', 'pins':[
            Pin(num='1',name='I/O2L',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='I/O0R',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='I/O1R',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='I/O2R',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='I/O3R',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='I/O4R',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='I/O5R',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='I/O6R',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='I/O7R',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='~{OE}R',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='I/O3L',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='R/~{W}R',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{SEM}R',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{CE}R',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A13R',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='A12R',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A11R',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A10R',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A9R',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A8R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I/O4L',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='A7R',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6R',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A5R',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A4R',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A3R',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A2R',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A1R',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A0R',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='~{INT}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='~{BUSY}R',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='I/O5L',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='M/~{S}',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='~{BUSY}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='~{INT}L',func=pin_types.OUTPUT,unit=1),
            Pin(num='44',name='A0L',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='A1L',func=pin_types.INPUT,unit=1),
            Pin(num='46',name='A2L',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='A3L',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='A4L',func=pin_types.INPUT,unit=1),
            Pin(num='49',name='A5L',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='50',name='A6L',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='A7L',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='A8L',func=pin_types.INPUT,unit=1),
            Pin(num='53',name='A9L',func=pin_types.INPUT,unit=1),
            Pin(num='54',name='A10L',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='A11L',func=pin_types.INPUT,unit=1),
            Pin(num='56',name='A12L',func=pin_types.INPUT,unit=1),
            Pin(num='57',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='58',name='A13L',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='~{CE}L',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I/O6L',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='~{SEM}L',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='R/~{W}L',func=pin_types.INPUT,unit=1),
            Pin(num='62',name='~{OE}L',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='I/O0L',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='I/O1L',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='I/O7L',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7027_TQ100', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7027_TQ100'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7027_TQ100\n\n', 'pins':[
            Pin(num='1',name='A9L',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='LBL',func=pin_types.INPUT,unit=1),
            Pin(num='100',name='A8L',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='UBL',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='CE0L',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CE1L',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SEML',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='R/WL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='OEL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='A10L',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I/O15L',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='I/O14L',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='I/O13L',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I/O12L',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='I/O11L',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='I/O10L',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='I/O9L',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='I/O8L',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='I/O7L',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A11L',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='I/O6L',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='I/O5L',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='I/O4L',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='I/O3L',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='I/O2L',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='I/O1L',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='I/O0L',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='I/O0R',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='A12L',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='I/O1R',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='I/O2R',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='I/O3R',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='I/O4R',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='I/O5R',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='I/O6R',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='I/O7R',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='I/O8R',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='I/O9R',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='A13L',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='I/O10R',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='I/O11R',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='I/O12R',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='I/O13R',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='I/O14R',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='I/O15R',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='OER',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A14L',func=pin_types.INPUT,unit=1),
            Pin(num='60',name='R/WR',func=pin_types.INPUT,unit=1),
            Pin(num='61',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='SEMR',func=pin_types.INPUT,unit=1),
            Pin(num='63',name='CE1R',func=pin_types.INPUT,unit=1),
            Pin(num='64',name='CE0R',func=pin_types.INPUT,unit=1),
            Pin(num='65',name='UBR',func=pin_types.INPUT,unit=1),
            Pin(num='66',name='LBR',func=pin_types.INPUT,unit=1),
            Pin(num='70',name='A14R',func=pin_types.INPUT,unit=1),
            Pin(num='71',name='A13R',func=pin_types.INPUT,unit=1),
            Pin(num='72',name='A12R',func=pin_types.INPUT,unit=1),
            Pin(num='73',name='A11R',func=pin_types.INPUT,unit=1),
            Pin(num='74',name='A10R',func=pin_types.INPUT,unit=1),
            Pin(num='75',name='A9R',func=pin_types.INPUT,unit=1),
            Pin(num='76',name='A8R',func=pin_types.INPUT,unit=1),
            Pin(num='77',name='A7R',func=pin_types.INPUT,unit=1),
            Pin(num='78',name='A6R',func=pin_types.INPUT,unit=1),
            Pin(num='79',name='A5R',func=pin_types.INPUT,unit=1),
            Pin(num='80',name='A4R',func=pin_types.INPUT,unit=1),
            Pin(num='81',name='A3R',func=pin_types.INPUT,unit=1),
            Pin(num='82',name='A2R',func=pin_types.INPUT,unit=1),
            Pin(num='83',name='A1R',func=pin_types.INPUT,unit=1),
            Pin(num='84',name='A0R',func=pin_types.INPUT,unit=1),
            Pin(num='85',name='INTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='86',name='BUSYR',func=pin_types.BIDIR,unit=1),
            Pin(num='87',name='M/S',func=pin_types.INPUT,unit=1),
            Pin(num='88',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='89',name='BUSYL',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='INTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='92',name='A0L',func=pin_types.INPUT,unit=1),
            Pin(num='93',name='A1L',func=pin_types.INPUT,unit=1),
            Pin(num='94',name='A2L',func=pin_types.INPUT,unit=1),
            Pin(num='95',name='A3L',func=pin_types.INPUT,unit=1),
            Pin(num='96',name='A4L',func=pin_types.INPUT,unit=1),
            Pin(num='97',name='A5L',func=pin_types.INPUT,unit=1),
            Pin(num='98',name='A6L',func=pin_types.INPUT,unit=1),
            Pin(num='99',name='A7L',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7132', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7132'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7132\n\n', 'pins':[
            Pin(num='1',name='/CEL',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A4L',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A5L',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A6L',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A7L',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A8L',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A9L',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='I/O0L',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='I/O1L',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='I/O2L',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='I/O3L',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='R/WL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I/O4L',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='I/O5L',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='I/O6L',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='I/O7L',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='I/O0R',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='I/O1R',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='I/O2R',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='I/O3R',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='I/O4R',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='/BSYL',func=pin_types.OUTPUT,unit=1),
            Pin(num='30',name='I/O5R',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='I/O6R',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='I/O7R',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A9R',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A8R',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A7R',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A6R',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='A5R',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A4R',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A3R',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A10L',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A2R',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A1R',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='A0R',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='/OER',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='A10R',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='/BSYR',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='R/WR',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='/CER',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='/OEL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A0L',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A1L',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2L',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3L',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT71V65903S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT71V65903S'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT71V65903S\n\n', 'pins':[
            Pin(num='A10',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='A11',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='A3',name='/CE1',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='/BW2',func=pin_types.INPUT,unit=1),
            Pin(num='A6',name='/CE2',func=pin_types.INPUT,unit=1),
            Pin(num='A7',name='/CEN',func=pin_types.INPUT,unit=1),
            Pin(num='A8',name='ADV/LD',func=pin_types.INPUT,unit=1),
            Pin(num='A9',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='B10',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='B2',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='B3',name='CE2',func=pin_types.INPUT,unit=1),
            Pin(num='B5',name='/BW1',func=pin_types.INPUT,unit=1),
            Pin(num='B6',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='R/W',func=pin_types.INPUT,unit=1),
            Pin(num='B8',name='/OE',func=pin_types.INPUT,unit=1),
            Pin(num='C11',name='IOP1',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='C4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D11',name='IO7',func=pin_types.BIDIR,unit=1),
            Pin(num='D2',name='IO8',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E11',name='IO6',func=pin_types.BIDIR,unit=1),
            Pin(num='E2',name='IO9',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='IO5',func=pin_types.BIDIR,unit=1),
            Pin(num='F2',name='IO10',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='G11',name='IO4',func=pin_types.BIDIR,unit=1),
            Pin(num='G2',name='IO11',func=pin_types.BIDIR,unit=1),
            Pin(num='G3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='VSSx',func=pin_types.PASSIVE,unit=1),
            Pin(num='H11',name='ZZ',func=pin_types.INPUT,unit=1),
            Pin(num='H2',name='VDDx',func=pin_types.PASSIVE,unit=1),
            Pin(num='H4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='H5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='J1',name='IO12',func=pin_types.BIDIR,unit=1),
            Pin(num='J10',name='IO3',func=pin_types.BIDIR,unit=1),
            Pin(num='J3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='J5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='J9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='K1',name='IO13',func=pin_types.BIDIR,unit=1),
            Pin(num='K10',name='IO2',func=pin_types.BIDIR,unit=1),
            Pin(num='K3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='K9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='L1',name='IO14',func=pin_types.BIDIR,unit=1),
            Pin(num='L10',name='IO1',func=pin_types.BIDIR,unit=1),
            Pin(num='L3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='L4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='L8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='L9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='M1',name='IO15',func=pin_types.BIDIR,unit=1),
            Pin(num='M10',name='IO0',func=pin_types.BIDIR,unit=1),
            Pin(num='M3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='M4',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='M5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M6',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M7',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='M8',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='M9',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='N1',name='IOP2',func=pin_types.BIDIR,unit=1),
            Pin(num='N3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N7',name='VSSx',func=pin_types.PASSIVE,unit=1),
            Pin(num='N8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='N9',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='P10',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='P3',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='P4',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='P6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='P8',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='P9',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='R1',name='/LBO',func=pin_types.INPUT,unit=1),
            Pin(num='R10',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='R11',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='R3',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='R4',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='R6',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='R8',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='R9',name='A13',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7201', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7201'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7201\n\n', 'pins':[
            Pin(num='1',name='WR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q8',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RD',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='D8',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='XO',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='EF',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='FL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='FF',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7204', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7204'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7204\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IS42S16400J-xC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS42S16400J-xC'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/42-45S16400J.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS42S16400J-xC\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GNDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS43LQ32256A-062BLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS43LQ32256A-062BLI'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-200_10.0x14.5mm_Layout12x22_P0.80x0.65mm'], 'footprint':'Package_BGA:BGA-200_10.0x14.5mm_Layout12x22_P0.80x0.65mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/43-46LQ32256A-AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS43LQ32256A-062BLI\n\nDRAM MEMORY', 'pins':[
            Pin(num='A1',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='DQ8_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='DQ0_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='DQ7_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='DQ15_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='DMI1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='DQ9_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='DQ1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DMI0_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='DQ6_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='DQ14_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='DQS1_T_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='DQS0_T_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='DQS1_C_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='DQ10_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='DQ2_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='DQS0_C_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DQ5_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='DQ13_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='DQ11_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='DQ3_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='DQ4_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='DQ12_A',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='ODT_CA_A',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H10',name='CA3_A',func=pin_types.INPUT,unit=1),
            Pin(num='H11',name='CA4_A',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H2',name='CA0_A',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='CS0_A',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='CA2_A',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='CA5_A',func=pin_types.INPUT,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='CA1_A',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='CKE0_A',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J8',name='CK_T_A',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='CK_C_A',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='ZQ0',func=pin_types.INPUT,unit=2),
            Pin(num='A8',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA1',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA10',name='VDDQ',func=pin_types.PWRIN,unit=2),
            Pin(num='AA11',name='DQ8_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA2',name='DQ0_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA4',name='DQ7_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA8',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA9',name='DQ15_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB10',name='VSS',func=pin_types.PWRIN,unit=2),
            Pin(num='AB11',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB12',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB2',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB4',name='VDD2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB9',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='G11',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N1',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N10',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N12',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N3',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N5',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N8',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P11',name='CA5_B',func=pin_types.INPUT,unit=2),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P2',name='CA1_B',func=pin_types.INPUT,unit=2),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P4',name='CKE0_B',func=pin_types.INPUT,unit=2),
            Pin(num='P5',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='P8',name='CK_T_B',func=pin_types.INPUT,unit=2),
            Pin(num='P9',name='CK_C_B',func=pin_types.INPUT,unit=2),
            Pin(num='R1',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R10',name='CA3_B',func=pin_types.INPUT,unit=2),
            Pin(num='R11',name='CA4_B',func=pin_types.INPUT,unit=2),
            Pin(num='R12',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R2',name='CA0_B',func=pin_types.INPUT,unit=2),
            Pin(num='R3',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='R4',name='CS0_B',func=pin_types.INPUT,unit=2),
            Pin(num='R5',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R8',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R9',name='CA2_B',func=pin_types.INPUT,unit=2),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T11',name='RESET_N',func=pin_types.INPUT,unit=2),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='ODT_CA_B',func=pin_types.INPUT,unit=2),
            Pin(num='T3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T4',name='VDD1',func=pin_types.PWRIN,unit=2),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T9',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U1',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U10',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='U11',name='DQ11_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U2',name='DQ3_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='U4',name='DQ4_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='U8',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='U9',name='DQ12_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V10',name='DQS1_C_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='DQ10_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V2',name='DQ2_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='DQS0_C_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='DQ5_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V9',name='DQ13_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W10',name='DQS1_T_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W12',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W2',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W3',name='DQS0_T_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W5',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W8',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W9',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y10',name='DMI1_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='DQ9_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y2',name='DQ1_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='DMI0_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='DQ6_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y9',name='DQ14_B',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B8', 'G5', 'G8', 'E2', 'C1', 'E4', 'G9', 'B9', 'H1', 'E3', 'A1', 'H10', 'E8', 'C10', 'C12', 'H12', 'H11', 'C11', 'E1', 'H3', 'H2', 'E11', 'C2', 'H5', 'E5', 'C3', 'H4', 'C5', 'E10', 'C4', 'H8', 'C8', 'J1', 'H9', 'D1', 'A11', 'C9', 'J10', 'F3', 'D11', 'J12', 'D10', 'J11', 'F1', 'D12', 'E12', 'J3', 'D2', 'J2', 'D4', 'J5', 'A10', 'D3', 'J4', 'A12', 'D5', 'E9', 'J8', 'A2', 'D8', 'K1', 'A3', 'D9', 'J9', 'F10', 'K10', 'A9', 'F12', 'K11', 'A4', 'F11', 'F2', 'K12', 'B1', 'F5', 'F4', 'K2', 'B10', 'F8', 'K3', 'B12', 'B11', 'G1', 'K4', 'F9', 'G10', 'K5', 'B3', 'G12', 'B2', 'K8', 'G3', 'K9', 'B5', 'G2', 'B4', 'G4']},{'label': 'uB', 'num': 2, 'pin_nums': ['A5', 'Y12', 'N9', 'U12', 'P1', 'AA1', 'P10', 'U11', 'Y2', 'P12', 'U3', 'Y3', 'Y5', 'AA10', 'AA12', 'P11', 'U2', 'Y4', 'AA11', 'P3', 'U5', 'Y8', 'AA3', 'P2', 'U4', 'AA2', 'U8', 'P5', 'Y9', 'AA5', 'P4', 'V1', 'AA4', 'U9', 'AA8', 'P8', 'R1', 'AB1', 'P9', 'V10', 'V12', 'AA9', 'V11', 'AB11', 'R10', 'R12', 'AB10', 'R11', 'V2', 'AB12', 'V3', 'R3', 'V5', 'AB2', 'R2', 'V4', 'AB3', 'V8', 'R5', 'AB5', 'R4', 'W1', 'AB4', 'R8', 'V9', 'AB8', 'T1', 'W11', 'AB9', 'R9', 'W10', 'G11', 'T10', 'W12', 'N1', 'W2', 'T12', 'N10', 'T11', 'W4', 'N11', 'W3', 'T3', 'N12', 'T2', 'W5', 'N2', 'W8', 'T5', 'N3', 'T4', 'W9', 'N4', 'T8', 'Y1', 'N5', 'T9', 'N8', 'U1', 'Y10', 'A8', 'U10', 'Y11']}] }),
        Part(**{ 'name':'IS61C5128AL-10KLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS61C5128AL-10KLI'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOJ-36_10.16x23.49mm_P1.27mm'], 'footprint':'Package_SO:SOJ-36_10.16x23.49mm_P1.27mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS61C5128AL-10KLI\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I/O0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS61C5128AL-10TLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS61C5128AL-10TLI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-44_10.16x18.41mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-44_10.16x18.41mm_P0.8mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS61C5128AL-10TLI\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I/O0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS61C5128AS-25HLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS61C5128AS-25HLI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-I-32_11.8x8mm_P0.5mm'], 'footprint':'Package_SO:TSOP-I-32_11.8x8mm_P0.5mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS61C5128AS-25HLI\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='I/O0',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='A17',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS61C5128AS-25QLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS61C5128AS-25QLI'}), 'ref_prefix':'U', 'fplist':['Package_SO:SSOP-32_11.305x20.495mm_P1.27mm'], 'footprint':'Package_SO:SSOP-32_11.305x20.495mm_P1.27mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS61C5128AS-25QLI\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I/O0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS61C5128AS-25TLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS61C5128AS-25TLI'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-32_21.0x10.2mm_P1.27mm'], 'footprint':'Package_SO:TSOP-II-32_21.0x10.2mm_P1.27mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS61C5128AS-25TLI\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='I/O0',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A3',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS62C256AL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS62C256AL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-28_8.4x18.16mm_P1.27mm'], 'footprint':'Package_SO:SOP-28_8.4x18.16mm_P1.27mm', 'keywords':'SRAM MEMORY ISSI parallel-interface', 'description':'', 'datasheet':'https://www.issi.com/WW/pdf/62-65C256AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS62C256AL\n\nSRAM MEMORY ISSI parallel-interface', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I/O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I/O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I/O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='I/O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='I/O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I/O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='I/O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='I/O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'KM62256CLP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'KM62256CLP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'https://www.futurlec.com/Datasheet/Memory/62256.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nKM62256CLP\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC16M16A2TG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC16M16A2TG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 16Mbx16 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC16M16A2TG\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 16Mbx16 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DQML',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQMH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC32M8A2TG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC32M8A2TG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 32Mbx8 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC32M8A2TG\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 32Mbx8 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC64M4A2TG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC64M4A2TG'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 64Mbx4 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC64M4A2TG\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 64Mbx4 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W9812G6KH-5', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W9812G6KH-5'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/da00-w9812g6khc1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nW9812G6KH-5\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BS0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BS1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10/AP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'CY62256-70PC', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'CY62256-70PC'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'https://ecee.colorado.edu/~mcclurel/Cypress_SRAM_CY62256.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nCY62256-70PC\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HM62256BLP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HM62256BLP'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm', 'Package_DIP:DIP-28_W15.24mm'], 'footprint':'Package_DIP:DIP-28_W15.24mm', 'keywords':'RAM SRAM CMOS MEMORY', 'description':'', 'datasheet':'https://web.mit.edu/6.115/www/document/62256.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nHM62256BLP\n\nRAM SRAM CMOS MEMORY', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='1',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='Q0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7202', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7202'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'', 'description':'', 'datasheet':'', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7202\n\n', 'pins':[
            Pin(num='1',name='WR',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='Q1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='Q2',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='Q3',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='Q8',func=pin_types.TRISTATE,unit=1),
            Pin(num='14',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='RD',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='Q4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='Q5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='Q6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='Q7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='D8',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='XO',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='EF',func=pin_types.OUTPUT,unit=1),
            Pin(num='22',name='CLR',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='FL',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='D7',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D6',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='D5',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='D4',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='D2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XI',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='FF',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='Q0',func=pin_types.TRISTATE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7203', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7203'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7203\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7205', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7205'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7205\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7206', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7206'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7206\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7207', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7207'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7207\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IDT7208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IDT7208'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm', 'Package_DIP:DIP-28_W7.62mm'], 'footprint':'Package_DIP:DIP-28_W7.62mm', 'keywords':'asynchronous fifo memory', 'description':'', 'datasheet':'http://www.idt.com/document/7203-7208-datasheet', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIDT7208\n\nasynchronous fifo memory', 'pins':[
            Pin(num='1',name='~{W}',func=pin_types.INPUT),
            Pin(num='10',name='Q1',func=pin_types.OUTPUT),
            Pin(num='11',name='Q2',func=pin_types.OUTPUT),
            Pin(num='12',name='Q3',func=pin_types.OUTPUT),
            Pin(num='13',name='Q8',func=pin_types.OUTPUT),
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='15',name='~{R}',func=pin_types.INPUT),
            Pin(num='16',name='Q4',func=pin_types.OUTPUT),
            Pin(num='17',name='Q5',func=pin_types.OUTPUT),
            Pin(num='18',name='Q6',func=pin_types.OUTPUT),
            Pin(num='19',name='Q7',func=pin_types.OUTPUT),
            Pin(num='2',name='D8',func=pin_types.INPUT),
            Pin(num='20',name='~{HF}/~{XO}',func=pin_types.OUTPUT),
            Pin(num='21',name='~{EF}',func=pin_types.OUTPUT),
            Pin(num='22',name='~{RS}',func=pin_types.INPUT),
            Pin(num='23',name='~{FL}/~{RT}',func=pin_types.INPUT),
            Pin(num='24',name='D7',func=pin_types.INPUT),
            Pin(num='25',name='D6',func=pin_types.INPUT),
            Pin(num='26',name='D5',func=pin_types.INPUT),
            Pin(num='27',name='D4',func=pin_types.INPUT),
            Pin(num='28',name='VCC',func=pin_types.PWRIN),
            Pin(num='3',name='D3',func=pin_types.INPUT),
            Pin(num='4',name='D2',func=pin_types.INPUT),
            Pin(num='5',name='D1',func=pin_types.INPUT),
            Pin(num='6',name='D0',func=pin_types.INPUT),
            Pin(num='7',name='~{XI}',func=pin_types.INPUT),
            Pin(num='8',name='~{FF}',func=pin_types.OUTPUT),
            Pin(num='9',name='Q0',func=pin_types.OUTPUT)], 'unit_defs':[] }),
        Part(**{ 'name':'IS42S16400J-xT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS42S16400J-xT'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/42-45S16400J.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS42S16400J-xT\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='GNDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GNDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS43LQ32256AL-062BLI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS43LQ32256AL-062BLI'}), 'ref_prefix':'U', 'fplist':['Package_BGA:BGA-200_10.0x14.5mm_Layout12x22_P0.80x0.65mm', 'Package_BGA:BGA-200_10.0x14.5mm_Layout12x22_P0.80x0.65mm'], 'footprint':'Package_BGA:BGA-200_10.0x14.5mm_Layout12x22_P0.80x0.65mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/43-46LQ32256AL-AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS43LQ32256AL-062BLI\n\nDRAM MEMORY', 'pins':[
            Pin(num='A1',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A10',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='A11',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A2',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='VDD2',func=pin_types.PWRIN,unit=1),
            Pin(num='A9',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B10',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='B11',name='DQ8_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B12',name='DNU',func=pin_types.NOCONNECT,unit=1),
            Pin(num='B2',name='DQ0_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B4',name='DQ7_A',func=pin_types.BIDIR,unit=1),
            Pin(num='B5',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B8',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='B9',name='DQ15_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C10',name='DMI1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C11',name='DQ9_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C2',name='DQ1_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C3',name='DMI0_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C4',name='DQ6_A',func=pin_types.BIDIR,unit=1),
            Pin(num='C5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='DQ14_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D1',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D10',name='DQS1_T_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D12',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D3',name='DQS0_T_A',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='D5',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D8',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E10',name='DQS1_C_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E11',name='DQ10_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='DQ2_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='DQS0_C_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E4',name='DQ5_A',func=pin_types.BIDIR,unit=1),
            Pin(num='E5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='DQ13_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F1',name='VDD1',func=pin_types.PWRIN,unit=1),
            Pin(num='F10',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F11',name='DQ11_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F12',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='F2',name='DQ3_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F3',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='F4',name='DQ4_A',func=pin_types.BIDIR,unit=1),
            Pin(num='F5',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='F8',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='DQ12_A',func=pin_types.BIDIR,unit=1),
            Pin(num='G1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G2',name='ODT_CA_A',func=pin_types.INPUT,unit=1),
            Pin(num='G3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='G5',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G8',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='VDD1',func=pin_types.PASSIVE,unit=1),
            Pin(num='H1',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H10',name='CA3_A',func=pin_types.INPUT,unit=1),
            Pin(num='H11',name='CA4_A',func=pin_types.INPUT,unit=1),
            Pin(num='H12',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H2',name='CA0_A',func=pin_types.INPUT,unit=1),
            Pin(num='H3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H4',name='CS0_A',func=pin_types.INPUT,unit=1),
            Pin(num='H5',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H8',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='H9',name='CA2_A',func=pin_types.INPUT,unit=1),
            Pin(num='J1',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J10',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J11',name='CA5_A',func=pin_types.INPUT,unit=1),
            Pin(num='J12',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J2',name='CA1_A',func=pin_types.INPUT,unit=1),
            Pin(num='J3',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='CKE0_A',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='J8',name='CK_T_A',func=pin_types.INPUT,unit=1),
            Pin(num='J9',name='CK_C_A',func=pin_types.INPUT,unit=1),
            Pin(num='K1',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K10',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K11',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K12',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K2',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K3',name='VDD2',func=pin_types.PASSIVE,unit=1),
            Pin(num='K4',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='K5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='K9',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='A5',name='ZQ0',func=pin_types.INPUT,unit=2),
            Pin(num='A8',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA1',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA10',name='VDDQ',func=pin_types.PWRIN,unit=2),
            Pin(num='AA11',name='DQ8_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA12',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AA2',name='DQ0_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA3',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA4',name='DQ7_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AA5',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA8',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='AA9',name='DQ15_B',func=pin_types.BIDIR,unit=2),
            Pin(num='AB1',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB10',name='VSS',func=pin_types.PWRIN,unit=2),
            Pin(num='AB11',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB12',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB2',name='DNU',func=pin_types.NOCONNECT,unit=2),
            Pin(num='AB3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB4',name='VDD2',func=pin_types.PWRIN,unit=2),
            Pin(num='AB5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='AB9',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='G11',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N1',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N10',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N11',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N12',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N2',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N3',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='N4',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='N5',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N8',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='N9',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P10',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P11',name='CA5_B',func=pin_types.INPUT,unit=2),
            Pin(num='P12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P2',name='CA1_B',func=pin_types.INPUT,unit=2),
            Pin(num='P3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='P4',name='CKE0_B',func=pin_types.INPUT,unit=2),
            Pin(num='P5',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='P8',name='CK_T_B',func=pin_types.INPUT,unit=2),
            Pin(num='P9',name='CK_C_B',func=pin_types.INPUT,unit=2),
            Pin(num='R1',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R10',name='CA3_B',func=pin_types.INPUT,unit=2),
            Pin(num='R11',name='CA4_B',func=pin_types.INPUT,unit=2),
            Pin(num='R12',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R2',name='CA0_B',func=pin_types.INPUT,unit=2),
            Pin(num='R3',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='R4',name='CS0_B',func=pin_types.INPUT,unit=2),
            Pin(num='R5',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R8',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='R9',name='CA2_B',func=pin_types.INPUT,unit=2),
            Pin(num='T1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T10',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T11',name='RESET_N',func=pin_types.INPUT,unit=2),
            Pin(num='T12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T2',name='ODT_CA_B',func=pin_types.INPUT,unit=2),
            Pin(num='T3',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T4',name='VDD1',func=pin_types.PWRIN,unit=2),
            Pin(num='T5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='T9',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U1',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U10',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='U11',name='DQ11_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U12',name='VDD1',func=pin_types.PASSIVE,unit=2),
            Pin(num='U2',name='DQ3_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U3',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='U4',name='DQ4_B',func=pin_types.BIDIR,unit=2),
            Pin(num='U5',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='U8',name='VDD2',func=pin_types.PASSIVE,unit=2),
            Pin(num='U9',name='DQ12_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V10',name='DQS1_C_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V11',name='DQ10_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V2',name='DQ2_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V3',name='DQS0_C_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V4',name='DQ5_B',func=pin_types.BIDIR,unit=2),
            Pin(num='V5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='V9',name='DQ13_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W1',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W10',name='DQS1_T_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W11',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W12',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W2',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W3',name='DQS0_T_B',func=pin_types.BIDIR,unit=2),
            Pin(num='W4',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='W5',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W8',name='VDDQ',func=pin_types.PASSIVE,unit=2),
            Pin(num='W9',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y1',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y10',name='DMI1_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y11',name='DQ9_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y12',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y2',name='DQ1_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y3',name='DMI0_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y4',name='DQ6_B',func=pin_types.BIDIR,unit=2),
            Pin(num='Y5',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y8',name='VSS',func=pin_types.PASSIVE,unit=2),
            Pin(num='Y9',name='DQ14_B',func=pin_types.BIDIR,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['B8', 'J12', 'F1', 'B9', 'J2', 'F10', 'C1', 'J3', 'F11', 'C10', 'J4', 'F12', 'C11', 'J5', 'F2', 'C12', 'F3', 'J8', 'B11', 'C2', 'J9', 'F4', 'C3', 'K1', 'F5', 'C4', 'K10', 'F8', 'C5', 'K11', 'F9', 'C8', 'K12', 'G1', 'B1', 'C9', 'K2', 'B10', 'G10', 'D1', 'K3', 'G12', 'A4', 'D10', 'K4', 'G2', 'A9', 'D11', 'K5', 'G3', 'D12', 'G4', 'K8', 'A3', 'D2', 'G5', 'A2', 'K9', 'D3', 'G8', 'A12', 'D4', 'G9', 'A1', 'A11', 'D5', 'H1', 'A10', 'D8', 'H10', 'D9', 'H11', 'E1', 'H12', 'E10', 'H2', 'E11', 'H3', 'E12', 'H4', 'E2', 'H5', 'B12', 'E3', 'H8', 'E4', 'B2', 'H9', 'E5', 'B3', 'J1', 'E8', 'B4', 'J10', 'E9', 'B5', 'J11']},{'label': 'uB', 'num': 2, 'pin_nums': ['R2', 'AB12', 'V4', 'AB2', 'R3', 'V5', 'AB3', 'R4', 'V8', 'R5', 'AB4', 'V9', 'AB5', 'R8', 'W1', 'R9', 'AB8', 'W10', 'T1', 'AB9', 'W11', 'G11', 'T10', 'W12', 'N1', 'T11', 'W2', 'T12', 'N10', 'W3', 'N11', 'T2', 'W4', 'T3', 'N12', 'W5', 'N2', 'T4', 'W8', 'T5', 'N3', 'W9', 'N4', 'T8', 'Y1', 'T9', 'N5', 'Y10', 'R12', 'N8', 'U1', 'Y11', 'A5', 'N9', 'U10', 'Y12', 'A8', 'P1', 'U11', 'Y2', 'AA1', 'P10', 'U12', 'Y3', 'AA10', 'P11', 'U2', 'Y4', 'AA11', 'U3', 'P12', 'Y5', 'AA12', 'P2', 'U4', 'Y8', 'AA2', 'U5', 'P3', 'Y9', 'AA3', 'U8', 'P4', 'AA4', 'P5', 'U9', 'AA5', 'V1', 'P8', 'AA8', 'P9', 'V10', 'AA9', 'R1', 'V11', 'AB1', 'V12', 'R10', 'AB10', 'R11', 'V2', 'AB11', 'V3']}] }),
        Part(**{ 'name':'IS64C5128AL-12CTLA3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS64C5128AL-12CTLA3'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-44_10.16x18.41mm_P0.8mm', 'Package_SO:TSOP-II-44_10.16x18.41mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-44_10.16x18.41mm_P0.8mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS64C5128AL-12CTLA3\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='41',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='I/O0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS64C5128AL-12KLA3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS64C5128AL-12KLA3'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOJ-36_10.16x23.49mm_P1.27mm', 'Package_SO:SOJ-36_10.16x23.49mm_P1.27mm'], 'footprint':'Package_SO:SOJ-36_10.16x23.49mm_P1.27mm', 'keywords':'SRAM MEMORY', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/61-64C5128AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS64C5128AL-12KLA3\n\nSRAM MEMORY', 'pins':[
            Pin(num='1',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='I/O2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='I/O3',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='I/O4',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='I/O5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='I/O6',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='30',name='I/O7',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A15',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A16',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A17',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A18',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I/O0',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='I/O1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS65C256AL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS65C256AL'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-28_8.4x18.16mm_P1.27mm', 'Package_SO:SOP-28_8.4x18.16mm_P1.27mm'], 'footprint':'Package_SO:SOP-28_8.4x18.16mm_P1.27mm', 'keywords':'SRAM MEMORY ISSI parallel-interface', 'description':'', 'datasheet':'https://www.issi.com/WW/pdf/62-65C256AL.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nIS65C256AL\n\nSRAM MEMORY ISSI parallel-interface', 'pins':[
            Pin(num='14',name='GND',func=pin_types.PWRIN),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='1',name='A14',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='I/O0',func=pin_types.TRISTATE,unit=1),
            Pin(num='12',name='I/O1',func=pin_types.TRISTATE,unit=1),
            Pin(num='13',name='I/O2',func=pin_types.TRISTATE,unit=1),
            Pin(num='15',name='I/O3',func=pin_types.TRISTATE,unit=1),
            Pin(num='16',name='I/O4',func=pin_types.TRISTATE,unit=1),
            Pin(num='17',name='I/O5',func=pin_types.TRISTATE,unit=1),
            Pin(num='18',name='I/O6',func=pin_types.TRISTATE,unit=1),
            Pin(num='19',name='I/O7',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='~{CE}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A13',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A1',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC16M16A2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC16M16A2P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 16Mbx16 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC16M16A2P\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 16Mbx16 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='DQML',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQMH',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC32M8A2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC32M8A2P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 32Mbx8 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC32M8A2P\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 32Mbx8 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MT48LC64M4A2P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MT48LC64M4A2P'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'SDRAM Synchronous DRAM PC100 PC133 256Mb 64Mbx4 MEMORY', 'description':'', 'datasheet':'https://www.micron.com/-/media/client/global/documents/products/data-sheet/dram/256mb_sdr.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nMT48LC64M4A2P\n\nSDRAM Synchronous DRAM PC100 PC133 256Mb 64Mbx4 MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='BA0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BA1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='A12',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='DQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W9812G6KH-6', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W9812G6KH-6'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/da00-w9812g6khc1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nW9812G6KH-6\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BS0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BS1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10/AP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W9812G6KH-6I', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W9812G6KH-6I'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/da00-w9812g6khc1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nW9812G6KH-6I\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BS0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BS1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10/AP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'W9812G6KH-75', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'W9812G6KH-75'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm'], 'footprint':'Package_SO:TSOP-II-54_22.2x10.16mm_P0.8mm', 'keywords':'DRAM MEMORY', 'description':'', 'datasheet':'https://www.winbond.com/resource-files/da00-w9812g6khc1.pdf', 'search_text':'/usr/share/kicad/symbols/Memory_RAM.kicad_sym\nW9812G6KH-75\n\nDRAM MEMORY', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DQ5',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DQ6',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='DQ7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LDQM',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{WE}',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{CAS}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{RAS}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='~{CS}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='DQ0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='BS0',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='BS1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='A10/AP',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='A3',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='A4',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDDQ',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='A5',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='A6',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='A7',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='A8',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='A9',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='A11',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='CKE',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='UDQM',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DQ1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='DQ8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='DQ9',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='DQ10',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='DQ11',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='DQ12',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='VDDQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DQ2',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='DQ13',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='DQ14',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VSSQ',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='DQ15',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSSQ',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='DQ3',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='DQ4',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VDDQ',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])